==> huaweicloudsdkeg-3.1.135-py2.py3-none-any.whl: huaweicloudsdkeg/v1/model/header_parameter.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class HeaderParameter:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'is_value_secret': 'bool',
        'key': 'str',
        'value': 'str'
    }

    attribute_map = {
        'is_value_secret': 'is_value_secret',
        'key': 'key',
        'value': 'value'
    }

    def __init__(self, is_value_secret=None, key=None, value=None):
        """HeaderParameter

        The model defined in huaweicloud sdk

        :param is_value_secret: 是否加密
        :type is_value_secret: bool
        :param key: header的key值
        :type key: str
        :param value: deader的value值
        :type value: str
        """
        
        

        self._is_value_secret = None
        self._key = None
        self._value = None
        self.discriminator = None

        if is_value_secret is not None:
            self.is_value_secret = is_value_secret
        if key is not None:
            self.key = key
        if value is not None:
            self.value = value

    @property
    def is_value_secret(self):
        """Gets the is_value_secret of this HeaderParameter.

        是否加密

        :return: The is_value_secret of this HeaderParameter.
        :rtype: bool
        """
        return self._is_value_secret

    @is_value_secret.setter
    def is_value_secret(self, is_value_secret):
        """Sets the is_value_secret of this HeaderParameter.

        是否加密

        :param is_value_secret: The is_value_secret of this HeaderParameter.
        :type is_value_secret: bool
        """
        self._is_value_secret = is_value_secret

    @property
    def key(self):
        """Gets the key of this HeaderParameter.

        header的key值

        :return: The key of this HeaderParameter.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this HeaderParameter.

        header的key值

        :param key: The key of this HeaderParameter.
        :type key: str
        """
        self._key = key

    @property
    def value(self):
        """Gets the value of this HeaderParameter.

        deader的value值

        :return: The value of this HeaderParameter.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this HeaderParameter.

        deader的value值

        :param value: The value of this HeaderParameter.
        :type value: str
        """
        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HeaderParameter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeg-3.1.150-py2.py3-none-any.whl: huaweicloudsdkeg/v1/model/header_parameter.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class HeaderParameter:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'is_value_secret': 'bool',
        'key': 'str',
        'value': 'str'
    }

    attribute_map = {
        'is_value_secret': 'is_value_secret',
        'key': 'key',
        'value': 'value'
    }

    def __init__(self, is_value_secret=None, key=None, value=None):
        r"""HeaderParameter

        The model defined in huaweicloud sdk

        :param is_value_secret: 是否加密
        :type is_value_secret: bool
        :param key: header的key值
        :type key: str
        :param value: deader的value值
        :type value: str
        """
        
        

        self._is_value_secret = None
        self._key = None
        self._value = None
        self.discriminator = None

        if is_value_secret is not None:
            self.is_value_secret = is_value_secret
        if key is not None:
            self.key = key
        if value is not None:
            self.value = value

    @property
    def is_value_secret(self):
        r"""Gets the is_value_secret of this HeaderParameter.

        是否加密

        :return: The is_value_secret of this HeaderParameter.
        :rtype: bool
        """
        return self._is_value_secret

    @is_value_secret.setter
    def is_value_secret(self, is_value_secret):
        r"""Sets the is_value_secret of this HeaderParameter.

        是否加密

        :param is_value_secret: The is_value_secret of this HeaderParameter.
        :type is_value_secret: bool
        """
        self._is_value_secret = is_value_secret

    @property
    def key(self):
        r"""Gets the key of this HeaderParameter.

        header的key值

        :return: The key of this HeaderParameter.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        r"""Sets the key of this HeaderParameter.

        header的key值

        :param key: The key of this HeaderParameter.
        :type key: str
        """
        self._key = key

    @property
    def value(self):
        r"""Gets the value of this HeaderParameter.

        deader的value值

        :return: The value of this HeaderParameter.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        r"""Sets the value of this HeaderParameter.

        deader的value值

        :param value: The value of this HeaderParameter.
        :type value: str
        """
        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HeaderParameter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
